import React, {useState} from "react";
import { Person } from "../components/Person";
import "./PersonContainer.css";

type TPersonInfo = {
    name: string;
    age: string;
    show: boolean
}

export const PersonContainer = () => {
    const [personsInfo, setPersonsInfo] = useState<TPersonInfo[]>([
        {name: "John", age: "25", show: true}, 
        {name: "Donny", age: "18", show: true},
        {name: "Jack", age: "55", show: true},
        {name: "Dima", age: "35", show: true}
    ]);

    const [selectedPerson, setSelectedPerson] = useState<number | null>(null);

    const onClickHandler = (index: number) => {
        const copyState = personsInfo;
        copyState[index].age = "5";
        setPersonsInfo([...copyState]);
    };

    const onRemoveHandler = (index: number) => {
        const copyState = personsInfo;
        copyState.splice(index, 1);
        setPersonsInfo([...copyState]);
    };

    const onChangeHandler = (e: React.ChangeEvent<HTMLInputElement>, index: number) => {
        const copyState = personsInfo;
        copyState[index].name = e.target.value;
        setPersonsInfo([...copyState]);
    };

    const onChangeShowInput = (e: React.ChangeEvent<HTMLInputElement>) => {
        const index = personsInfo.findIndex(item => item.name === e.target.value);
        if(index >= 0) {
            setSelectedPerson(index);
        }
    };

    const onClickShow = () => {
        const copyState = personsInfo;
        copyState[selectedPerson!].show = true;
        setPersonsInfo([...copyState]);
    };

    const onClickHide = () => {
        const copyState = personsInfo;
        copyState[selectedPerson!].show = false;
        setPersonsInfo([...copyState]);
    }

    return (
        <div className="PersonContainer">
            {
                personsInfo.map((item, index) => (
                    item.show ? 
                    <Person 
                        key={index}
                        name={item.name} 
                        age={item.age} 
                        onClick={() => onClickHandler(index)}
                        onRemove={() => onRemoveHandler(index)}
                        onChange={(e) => onChangeHandler(e, index)}
                    /> : null
                ))
            }

            <input className="inp" type="text" onChange={onChangeShowInput}/>
            <button className="show" onClick={onClickShow}>Show</button>
            <button className="hide" onClick={onClickHide}>Hide</button>
        </div>
    );
};